tietools.are_components_in_same_tie_spanner
===========================================

.. autofunction:: abjad.tools.tietools.are_components_in_same_tie_spanner.are_components_in_same_tie_spanner
   :noindex:
